# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

import plugin_pb2 as plugin__pb2


class NodeStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Init = channel.unary_unary(
        '/proto.Node/Init',
        request_serializer=plugin__pb2.InitRequest.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.OnCreate = channel.unary_unary(
        '/proto.Node/OnCreate',
        request_serializer=plugin__pb2.OnCreateRequest.SerializeToString,
        response_deserializer=plugin__pb2.OnCreateResponse.FromString,
        )
    self.OnMessage = channel.unary_unary(
        '/proto.Node/OnMessage',
        request_serializer=plugin__pb2.OnMessageRequest.SerializeToString,
        response_deserializer=plugin__pb2.OnMessageResponse.FromString,
        )
    self.OnClose = channel.unary_unary(
        '/proto.Node/OnClose',
        request_serializer=plugin__pb2.OnCloseRequest.SerializeToString,
        response_deserializer=plugin__pb2.OnCloseResponse.FromString,
        )


class NodeServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Init(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OnCreate(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OnMessage(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def OnClose(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_NodeServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Init': grpc.unary_unary_rpc_method_handler(
          servicer.Init,
          request_deserializer=plugin__pb2.InitRequest.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'OnCreate': grpc.unary_unary_rpc_method_handler(
          servicer.OnCreate,
          request_deserializer=plugin__pb2.OnCreateRequest.FromString,
          response_serializer=plugin__pb2.OnCreateResponse.SerializeToString,
      ),
      'OnMessage': grpc.unary_unary_rpc_method_handler(
          servicer.OnMessage,
          request_deserializer=plugin__pb2.OnMessageRequest.FromString,
          response_serializer=plugin__pb2.OnMessageResponse.SerializeToString,
      ),
      'OnClose': grpc.unary_unary_rpc_method_handler(
          servicer.OnClose,
          request_deserializer=plugin__pb2.OnCloseRequest.FromString,
          response_serializer=plugin__pb2.OnCloseResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'proto.Node', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))


class RuntimeHelperStub(object):
  # missing associated documentation comment in .proto file
  pass

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.Close = channel.unary_unary(
        '/proto.RuntimeHelper/Close',
        request_serializer=plugin__pb2.Empty.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.Debug = channel.unary_unary(
        '/proto.RuntimeHelper/Debug',
        request_serializer=plugin__pb2.DebugRequest.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.EmitFlowEvent = channel.unary_unary(
        '/proto.RuntimeHelper/EmitFlowEvent',
        request_serializer=plugin__pb2.EmitFlowEventRequest.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.EmitOutput = channel.unary_unary(
        '/proto.RuntimeHelper/EmitOutput',
        request_serializer=plugin__pb2.EmitOutputRequest.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.EmitError = channel.unary_unary(
        '/proto.RuntimeHelper/EmitError',
        request_serializer=plugin__pb2.EmitErrorRequest.SerializeToString,
        response_deserializer=plugin__pb2.Empty.FromString,
        )
    self.GetVaultItem = channel.unary_unary(
        '/proto.RuntimeHelper/GetVaultItem',
        request_serializer=plugin__pb2.GetVaultItemRequest.SerializeToString,
        response_deserializer=plugin__pb2.GetVaultItemResponse.FromString,
        )
    self.GetIntVariable = channel.unary_unary(
        '/proto.RuntimeHelper/GetIntVariable',
        request_serializer=plugin__pb2.GetVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.GetIntVariableResponse.FromString,
        )
    self.GetStringVariable = channel.unary_unary(
        '/proto.RuntimeHelper/GetStringVariable',
        request_serializer=plugin__pb2.GetVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.GetStringVariableResponse.FromString,
        )
    self.GetInterfaceVariable = channel.unary_unary(
        '/proto.RuntimeHelper/GetInterfaceVariable',
        request_serializer=plugin__pb2.GetVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.GetInterfaceVariableResponse.FromString,
        )
    self.SetIntVariable = channel.unary_unary(
        '/proto.RuntimeHelper/SetIntVariable',
        request_serializer=plugin__pb2.SetIntVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.SetVariableResponse.FromString,
        )
    self.SetStringVariable = channel.unary_unary(
        '/proto.RuntimeHelper/SetStringVariable',
        request_serializer=plugin__pb2.SetStringVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.SetVariableResponse.FromString,
        )
    self.SetInterfaceVariable = channel.unary_unary(
        '/proto.RuntimeHelper/SetInterfaceVariable',
        request_serializer=plugin__pb2.SetInterfaceVariableRequest.SerializeToString,
        response_deserializer=plugin__pb2.SetVariableResponse.FromString,
        )


class RuntimeHelperServicer(object):
  # missing associated documentation comment in .proto file
  pass

  def Close(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def Debug(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EmitFlowEvent(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EmitOutput(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def EmitError(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetVaultItem(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetIntVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetStringVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def GetInterfaceVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetIntVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetStringVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def SetInterfaceVariable(self, request, context):
    # missing associated documentation comment in .proto file
    pass
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RuntimeHelperServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'Close': grpc.unary_unary_rpc_method_handler(
          servicer.Close,
          request_deserializer=plugin__pb2.Empty.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'Debug': grpc.unary_unary_rpc_method_handler(
          servicer.Debug,
          request_deserializer=plugin__pb2.DebugRequest.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'EmitFlowEvent': grpc.unary_unary_rpc_method_handler(
          servicer.EmitFlowEvent,
          request_deserializer=plugin__pb2.EmitFlowEventRequest.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'EmitOutput': grpc.unary_unary_rpc_method_handler(
          servicer.EmitOutput,
          request_deserializer=plugin__pb2.EmitOutputRequest.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'EmitError': grpc.unary_unary_rpc_method_handler(
          servicer.EmitError,
          request_deserializer=plugin__pb2.EmitErrorRequest.FromString,
          response_serializer=plugin__pb2.Empty.SerializeToString,
      ),
      'GetVaultItem': grpc.unary_unary_rpc_method_handler(
          servicer.GetVaultItem,
          request_deserializer=plugin__pb2.GetVaultItemRequest.FromString,
          response_serializer=plugin__pb2.GetVaultItemResponse.SerializeToString,
      ),
      'GetIntVariable': grpc.unary_unary_rpc_method_handler(
          servicer.GetIntVariable,
          request_deserializer=plugin__pb2.GetVariableRequest.FromString,
          response_serializer=plugin__pb2.GetIntVariableResponse.SerializeToString,
      ),
      'GetStringVariable': grpc.unary_unary_rpc_method_handler(
          servicer.GetStringVariable,
          request_deserializer=plugin__pb2.GetVariableRequest.FromString,
          response_serializer=plugin__pb2.GetStringVariableResponse.SerializeToString,
      ),
      'GetInterfaceVariable': grpc.unary_unary_rpc_method_handler(
          servicer.GetInterfaceVariable,
          request_deserializer=plugin__pb2.GetVariableRequest.FromString,
          response_serializer=plugin__pb2.GetInterfaceVariableResponse.SerializeToString,
      ),
      'SetIntVariable': grpc.unary_unary_rpc_method_handler(
          servicer.SetIntVariable,
          request_deserializer=plugin__pb2.SetIntVariableRequest.FromString,
          response_serializer=plugin__pb2.SetVariableResponse.SerializeToString,
      ),
      'SetStringVariable': grpc.unary_unary_rpc_method_handler(
          servicer.SetStringVariable,
          request_deserializer=plugin__pb2.SetStringVariableRequest.FromString,
          response_serializer=plugin__pb2.SetVariableResponse.SerializeToString,
      ),
      'SetInterfaceVariable': grpc.unary_unary_rpc_method_handler(
          servicer.SetInterfaceVariable,
          request_deserializer=plugin__pb2.SetInterfaceVariableRequest.FromString,
          response_serializer=plugin__pb2.SetVariableResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'proto.RuntimeHelper', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



from node import Node


def node_decorator(*args, **kwargs):
    def wrapper(cls):
        class NewCls(cls):
            def __init__(self):
                self.cls = cls

            def __getattribute__(self, s):
                if s in kwargs:
                    return kwargs[s]

                return super().__getattribute__(s)

        return NewCls
    return wrapper



from concurrent import futures
import grpc
import asyncio
import sys, inspect

import health_pb2
import health_pb2_grpc
import plugin_pb2_grpc
import health

from factory import NodeFactory
from node import NodeServicer, Node
from runtime import Runtime
from spec import Spec


async def start():

    if len(sys.argv) > 3 and sys.argv[1] == '-s':
        Spec.generate(sys.argv[2], sys.argv[3])
        return

    init()

    healthServicer = health.HealthServicer()
    healthServicer.set_status("plugin", 1)

    server = grpc.server(futures.ThreadPoolExecutor(max_workers=10))
    health_pb2_grpc.add_HealthServicer_to_server(healthServicer, server)
    plugin_pb2_grpc.add_NodeServicer_to_server(NodeServicer(), server)

    port = server.add_insecure_port('[::]:0')
    server.start()

    print("1|1|tcp|127.0.0.1:%d|grpc\n" % port, flush=True)

    Runtime.event.wait()
    Runtime.close()


def init():
    frm = inspect.stack()[2]
    mod = inspect.getmodule(frm[0])
    clsmembers = inspect.getmembers(sys.modules[mod.__name__], inspect.isclass)
    for c in clsmembers:
        if issubclass(c[1], Node) and c[1] is not Node:
            cls = c[1]
            name = cls().id
            factory = NodeFactory(cls)
            Runtime.create_node(name, factory)



import gzip
import plugin_pb2
import json
import threading
from google.protobuf import json_format
from struct_pb2 import Struct

from plugin_pb2_grpc import RuntimeHelperStub

from types import SimpleNamespace as Namespace


class Variable:
    def __init__(self, scope: str, name: str):
        self.scope = scope
        self.name = name


class Runtime:
    active_nodes = 0
    client: RuntimeHelperStub = None
    event: threading.Event = threading.Event()
    factories = {}
    nodes = {}

    @staticmethod
    def set_client(client: RuntimeHelperStub):
        Runtime.client = client

    @staticmethod
    def create_node(name: str, factory):
        Runtime.factories[name] = factory

    @staticmethod
    def add_node(guid: str, node):
        Runtime.nodes[guid] = node

    @staticmethod
    def compress(data: bytes):
        return gzip.compress(data)

    @staticmethod
    def decompress(data: bytes):
        return gzip.decompress(data)

    @staticmethod
    def deserialize(data: bytes, c):
        node = c()
        obj = json.loads(data, object_hook=lambda d: Namespace(**d))
        for key in obj.__dict__.keys():
            node.__setattr__(key, obj.__dict__[key])
        return node

    @staticmethod
    def close():
        if Runtime.client is None:
            return

        request = plugin_pb2.Empty()
        Runtime.client.Close(request)

    @staticmethod
    def get_vault_item(vault_id: str, item_id: str):
        if Runtime.client is None:
            return {}

        request = plugin_pb2.GetVaultItemRequest(vaultId=vault_id, ItemId=item_id)
        response = Runtime.client.GetVaultItem(request)
        return json_format.MessageToDict(response.item)['value']

    @staticmethod
    def get_int_variable(variable: Variable, message: bytes):
        if Runtime.client is None:
            return 0

        var = plugin_pb2.Variable(scope=variable.scope, name=variable.name)
        request = plugin_pb2.GetVariableRequest(variable=var, message=message)
        response = Runtime.client.GetIntVariable(request)
        return response.value

    @staticmethod
    def get_string_variable(variable: Variable, message: bytes):
        if Runtime.client is None:
            return ""

        var = plugin_pb2.Variable(scope=variable.scope, name=variable.name)
        request = plugin_pb2.GetVariableRequest(variable=var, message=message)
        response = Runtime.client.GetStringVariable(request)
        return response.value

    @staticmethod
    def get_interface_variable(variable: Variable, message: bytes):
        if Runtime.client is None:
            return None

        var = plugin_pb2.Variable(scope=variable.scope, name=variable.name)
        request = plugin_pb2.GetVariableRequest(variable=var, message=message)
        response = Runtime.client.GetInterfaceVariable(request)

        return json_format.MessageToDict(response.value)['value']

    @staticmethod
    def set_int_variable(variable: Variable, message: bytes, value: int):
        if Runtime.client is None:
            return message

        var = plugin_pb2.Variable(scope=variable.scope, name=variable.name)
        request = plugin_pb2.SetIntVariableRequest(variable=var, message=message, value=value)
        response = Runtime.client.SetIntVariable(request)
        return response.message

    @staticmethod
    def set_string_variable(variable: Variable, message: bytes, value: str):
        if Runtime.client is None:
            return message

        var = plugin_pb2.Variable(scope=variable.scope, name=variable.name)
        request = plugin_pb2.SetStringVariableRequest(variable=var, message=message, value=value)
        response = Runtime.client.SetStringVariable(request)
        return response.message

    @staticmethod
    def set_interface_variable(variable: Variable, message: bytes, value: object):
        if Runtime.client is None:
            return message

        val = Struct()
        val.update({'value': value})

        var = plugin_pb2.Variable(scope=variable.scope, name=variable.name)
        request = plugin_pb2.SetInterfaceVariableRequest(variable=var, message=message, value=val)
        response = Runtime.client.SetInterfaceVariable(request)
        return response.message



import inspect, json, sys
from node import Node
from variable import Variable, Credentials, Enum


class NodeSpec:
    def __init__(self, id: str, icon: str='', name: str='', color: str='', inputs: int=0, outputs: int=0):
        self.id = id
        self.icon = icon
        self.name = name
        self.color = color
        self.inputs = inputs,
        self.outputs = outputs,
        self.properties = []


class Property:
    def __init__(self, schema):
        self.schema = schema
        self.formData = {}
        self.uiSchema = {}


class Schema:
    def __init__(self, type: str, title: str):
        self.type = type
        self.title = title
        self.properties = {}


class SProperty:
    type = ''
    title = ''
    subtitle = None
    category = None
    properties = None
    csScope = None
    jsScope = None
    customScope = None
    messageScope = None
    multiple = None
    variableType = None
    enum = []
    enumNames = []


class VarDataProperty:
    def __init__(self, name: str, scope: str):
        self.scope = scope
        self.name = name


class Spec:
    @staticmethod
    def generate(plugin_name, version):
        frm = inspect.stack()[2]
        mod = inspect.getmodule(frm[0])
        clsmembers = inspect.getmembers(sys.modules[mod.__name__], inspect.isclass)
        nodes = []

        for c in clsmembers:
            cls = c[1]
            if issubclass(cls, Node) and cls is not Node:
                id = cls().id
                name = cls().name

                spec = NodeSpec(id=id, name=name, inputs=1, outputs=1)  # FIX

                inProperty = Property(schema=Schema(title='Input', type='object'))
                outProperty = Property(schema=Schema(title='Output', type='object'))
                optProperty = Property(schema=Schema(title='Option', type='object'))

                props = []
                fields = cls().cls().__dict__
                for key in fields.keys():
                    val = fields[key]
                    if hasattr(val, 'title') and isinstance(val.title, str):
                        #print(key + ':' + fields[key].title)
                        title = val.title
                        sProp = SProperty()

                        isVar = isinstance(val, Variable)
                        isCred = isinstance(val, Credentials)
                        isEnum = isinstance(val, Enum)

                        if isVar:
                            sProp.type = 'object'
                            sProp.variableType = Spec.get_variable_type(val)
                            sProp.properties = {'scope': {'type': 'string'}, 'name': {'type': 'string'}}
                        elif isCred:
                            sProp.type = 'object'
                            sProp.subtitle = 'Credentials'
                            sProp.category = val.category
                            sProp.properties = {'vaultId': {'type': 'string'}, 'itemId': {'type': 'string'}}
                        elif isEnum:
                            sProp.type = val.type
                            sProp.enum = val.enum
                            sProp.enumNames = val.enumNames
                            sProp.multiple = True

                        else:
                            sProp.type = Spec.get_variable_type(val).lower()

                        if hasattr(val, 'csScope'):
                            sProp.csScope = True
                        if hasattr(val, 'customScope'):
                            sProp.customScope = True
                        if hasattr(val, 'jsScope'):
                            sProp.jsScope = True
                        if hasattr(val, 'messageScope'):
                            sProp.messageScope = True

                        lower_name = Spec.lower_first_letter(key)
                        if lower_name.startswith('in'):  # input
                            inProperty.schema.properties[lower_name] = sProp
                            inProperty.uiSchema['ui:order'] = ['*']  # FIX

                            if isVar:
                                inProperty.formData[lower_name] = VarDataProperty(name=val.name, scope=val.scope)
                                inProperty.uiSchema[lower_name] = {'ui:field': 'variable'}
                            elif isCred:
                                inProperty.uiSchema[lower_name] = {'ui:field': 'credentials'}
                            else:
                                inProperty.formData[lower_name] = val.value

                        elif lower_name.startswith('out'):  # output
                            outProperty.schema.properties[lower_name] = sProp
                            outProperty.uiSchema['ui:order'] = ['*']  # FIX

                            if isVar:
                                outProperty.formData[lower_name] = VarDataProperty(name=val.name, scope=val.scope)
                                outProperty.uiSchema[lower_name] = {'ui:field': 'variable'}
                            elif isCred:
                                outProperty.uiSchema[lower_name] = {'ui:field': 'credentials'}
                            else:
                                outProperty.formData[lower_name] = val.value

                        elif lower_name.startswith('opt'):  # option
                            optProperty.schema.properties[lower_name] = sProp
                            optProperty.uiSchema['ui:order'] = ['*']  # FIX

                            if isVar:
                                optProperty.formData[lower_name] = VarDataProperty(name=val.name, scope=val.scope)
                                optProperty.uiSchema[lower_name] = {'ui:field': 'variable'}
                            elif isCred:
                                optProperty.uiSchema[lower_name] = {'ui:field': 'credentials'}
                            else:
                                optProperty.formData[lower_name] = val.value

                if len(inProperty.schema.properties) > 0:
                    props.append(inProperty)
                if len(outProperty.schema.properties) > 0:
                    props.append(outProperty)
                if len(optProperty.schema.properties) > 0:
                    props.append(optProperty)

                spec.properties = props
                nodes.append(spec)

        js = json.dumps({'nodes': Spec.cleandict(nodes), 'name': plugin_name, 'version': version}, default=lambda o: o.__dict__)
        print(js)

    @staticmethod
    def cleandict(d):
        if not isinstance(d, dict):
            return d
        return dict((k, Spec.cleandict(v)) for k, v in d.iteritems() if v is not None)

    @staticmethod
    def get_variable_type(val) -> str:
        if isinstance(val, Variable):
            return Spec.upper_first_letter(val.type)

        return 'String'

    @staticmethod
    def lower_first_letter(text: str) -> str:
        if len(text) < 2:
            return text.lower()
        return text[:1].lower() + text[1:]

    @staticmethod
    def upper_first_letter(text: str) -> str:
        if len(text) < 2:
            return text.upper()
        return text[:1].upper() + text[1:]



from setuptools import find_packages, setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="robomotion", # Replace with your own username
    version="0.1.6",
    author="Robomotion IO",
    author_email="support@robomotion.io",
    description="Robomotion custom node package",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/pypa/sampleproject",
    include_package_data=True,
    packages=["."],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)